@@ -9,6 +9,7 @@ from typing import TYPE_CHECKING, Any, Optional, Protocol
 
 import pytest
 
+from libvcs import exc
 from libvcs._internal.run import run
 from libvcs.sync.git import GitRemote, GitSync
 from libvcs.sync.hg import HgSync
@@ -17,6 +18,14 @@ from libvcs.sync.svn import SvnSync
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
+
+class MaxUniqueRepoAttemptsExceeded(exc.LibVCSException):
+    def __init__(self, attempts: int, *args: object):
+        return super().__init__(
+            f"Could not find unused repo destination (attempts: {attempts})"
+        )
+
+
 skip_if_git_missing = pytest.mark.skipif(
     not shutil.which("git"), reason="git is not available"
 )
@@ -173,9 +182,7 @@ def unique_repo_name(remote_repos_path: pathlib.Path, max_retries: int = 15) ->
     attempts = 1
     while True:
         if attempts > max_retries:
-            raise Exception(
-                f"Could not find unused repo destination (attempts: {attempts})"
-            )
+            raise MaxUniqueRepoAttemptsExceeded(attempts=attempts)
         remote_repo_name: str = next(namer)
         suggestion = remote_repos_path / remote_repo_name
         if suggestion.exists():
@@ -203,11 +210,14 @@ class CreateProjectCallbackFixtureProtocol(Protocol):
         ...
 
 
+DEFAULT_GIT_REMOTE_REPO_CMD_ARGS = ["--bare"]
+
+
 def _create_git_remote_repo(
     remote_repos_path: pathlib.Path,
     remote_repo_name: str,
     remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
-    init_cmd_args: InitCmdArgs = ["--bare"],
+    init_cmd_args: InitCmdArgs = DEFAULT_GIT_REMOTE_REPO_CMD_ARGS,
 ) -> pathlib.Path:
     if init_cmd_args is None:
         init_cmd_args = []
@@ -231,7 +241,7 @@ def create_git_remote_repo(
         remote_repos_path: pathlib.Path = remote_repos_path,
         remote_repo_name: Optional[str] = None,
         remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
-        init_cmd_args: InitCmdArgs = ["--bare"],
+        init_cmd_args: InitCmdArgs = DEFAULT_GIT_REMOTE_REPO_CMD_ARGS,
     ) -> pathlib.Path:
         return _create_git_remote_repo(
             remote_repos_path=remote_repos_path,
@@ -276,7 +286,10 @@ def _create_svn_remote_repo(
         init_cmd_args = []
 
     remote_repo_path = remote_repos_path / remote_repo_name
-    run(["svnadmin", "create", remote_repo_path, *init_cmd_args])
+    run(["svnadmin", "create", str(remote_repo_path), *init_cmd_args])
+
+    assert remote_repo_path.exists()
+    assert remote_repo_path.is_dir()
 
     if remote_repo_post_init is not None and callable(remote_repo_post_init):
         remote_repo_post_init(remote_repo_path=remote_repo_path)
@@ -284,6 +297,23 @@ def _create_svn_remote_repo(
     return remote_repo_path
 
 
+def svn_remote_repo_single_commit_post_init(remote_repo_path: pathlib.Path) -> None:
+    assert remote_repo_path.exists()
+    repo_dumpfile = pathlib.Path(__file__).parent / "data" / "repotest.dump"
+    run(
+        " ".join(
+            [
+                "svnadmin",
+                "load",
+                str(remote_repo_path),
+                "<",
+                str(repo_dumpfile),
+            ]
+        ),
+        shell=True,
+    )
+
+
 @pytest.fixture
 @skip_if_svn_missing
 def create_svn_remote_repo(
@@ -313,10 +343,9 @@ def create_svn_remote_repo(
 @skip_if_svn_missing
 def svn_remote_repo(remote_repos_path: pathlib.Path) -> pathlib.Path:
     """Pre-made. Local file:// based SVN server."""
-    svn_repo_name = "svn_server_dir"
     remote_repo_path = _create_svn_remote_repo(
         remote_repos_path=remote_repos_path,
-        remote_repo_name=svn_repo_name,
+        remote_repo_name="svn_server_dir",
         remote_repo_post_init=None,
     )
 
@@ -456,7 +485,11 @@ def add_doctest_fixtures(
         doctest_namespace["create_git_remote_repo_bare"] = create_git_remote_repo
         doctest_namespace["git_local_clone"] = git_repo
     if shutil.which("svn"):
-        doctest_namespace["create_svn_remote_repo"] = create_svn_remote_repo
+        doctest_namespace["create_svn_remote_repo_bare"] = create_svn_remote_repo
+        doctest_namespace["create_svn_remote_repo"] = functools.partial(
+            create_svn_remote_repo,
+            remote_repo_post_init=svn_remote_repo_single_commit_post_init,
+        )
     if shutil.which("hg"):
         doctest_namespace["create_hg_remote_repo_bare"] = create_hg_remote_repo
         doctest_namespace["create_hg_remote_repo"] = functools.partial(
