@@ -20,11 +20,11 @@ class Obj:
     "items,filter_expr,expected_result",
     [
         [[Obj(test=1)], None, [Obj(test=1)]],
-        [[Obj(test=1)], dict(test=1), [Obj(test=1)]],
-        [[Obj(test=1)], dict(test=2), []],
+        [[Obj(test=1)], {"test": 1}, [Obj(test=1)]],
+        [[Obj(test=1)], {"test": 2}, []],
         [
             [Obj(test=2, fruit=["apple"])],
-            dict(fruit__in="apple"),
+            {"fruit__in": "apple"},
             QueryList([Obj(test=2, fruit=["apple"])]),
         ],
         [[{"test": 1}], None, [{"test": 1}]],
@@ -37,97 +37,97 @@ class Obj:
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__eq="apple"),
+            {"fruit__eq": "apple"},
             QueryList([{"fruit": "apple", "banana": object()}]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__eq="notmatch"),
+            {"fruit__eq": "notmatch"},
             QueryList([]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__exact="apple"),
+            {"fruit__exact": "apple"},
             QueryList([{"fruit": "apple", "banana": object()}]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__exact="notmatch"),
+            {"fruit__exact": "notmatch"},
             QueryList([]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__iexact="Apple"),
+            {"fruit__iexact": "Apple"},
             QueryList([{"fruit": "apple", "banana": object()}]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit__iexact="Notmatch"),
+            {"fruit__iexact": "Notmatch"},
             QueryList([]),
         ],
         [
             [{"fruit": "apple", "banana": object()}],
-            dict(fruit="notmatch"),
+            {"fruit": "notmatch"},
             QueryList([]),
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit="apple"),
+            {"fruit": "apple"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__in="app"),
+            {"fruit__in": "app"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__icontains="App"),
+            {"fruit__icontains": "App"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__contains="app"),
+            {"fruit__contains": "app"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__regex=r"app.*"),
+            {"fruit__regex": r"app.*"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__iregex=r"App.*"),
+            {"fruit__iregex": r"App.*"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__startswith="a"),
+            {"fruit__startswith": "a"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__istartswith="AP"),
+            {"fruit__istartswith": "AP"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__startswith="z"),
+            {"fruit__startswith": "z"},
             [],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__endswith="le"),
+            {"fruit__endswith": "le"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__iendswith="LE"),
+            {"fruit__iendswith": "LE"},
             [{"fruit": "apple"}],
         ],
         [
             [{"fruit": "apple"}, {"fruit": "mango"}],
-            dict(fruit__endswith="z"),
+            {"fruit__endswith": "z"},
             [],
         ],
         [
@@ -137,7 +137,7 @@ class Obj:
                 {"fruit": "banana"},
                 {"fruit": "kiwi"},
             ],
-            dict(fruit__in=["apple", "mango"]),
+            {"fruit__in": ["apple", "mango"]},
             [{"fruit": "apple"}, {"fruit": "mango"}],
         ],
         [
@@ -147,7 +147,7 @@ class Obj:
                 {"fruit": "banana"},
                 {"fruit": "kiwi"},
             ],
-            dict(fruit__nin=["apple", "mango"]),
+            {"fruit__nin": ["apple", "mango"]},
             [{"fruit": "banana"}, {"fruit": "kiwi"}],
         ],
         [
@@ -165,7 +165,7 @@ class Obj:
                     "state": "Florida",
                 },
             ],
-            dict(city="Tampa", state="Florida"),
+            {"city": "Tampa", "state": "Florida"},
             [
                 {"place": "book store", "city": "Tampa", "state": "Florida"},
                 {"place": "coffee shop", "city": "Tampa", "state": "Florida"},
@@ -186,7 +186,7 @@ class Obj:
                     "state": "Florida",
                 },
             ],
-            dict(place__contains="coffee", state="Florida"),
+            {"place__contains": "coffee", "state": "Florida"},
             [
                 {"place": "coffee shop", "city": "Tampa", "state": "Florida"},
             ],
@@ -206,7 +206,7 @@ class Obj:
                     "foods": {"fruit": ["apple", "cantelope"], "breakfast": "waffles"},
                 },
             ],
-            dict(foods__fruit__contains="banana"),
+            {"foods__fruit__contains": "banana"},
             [
                 {
                     "place": "Largo",
@@ -231,7 +231,7 @@ class Obj:
                     "foods": {"fruit": ["apple", "cantelope"], "breakfast": "waffles"},
                 },
             ],
-            dict(foods__breakfast="cereal"),
+            {"foods__breakfast": "cereal"},
             [
                 {
                     "place": "Largo",
@@ -244,8 +244,8 @@ class Obj:
         [[1, 2, 3, 4, 5], None, QueryList([1, 2, 3, 4, 5])],
         [[1, 2, 3, 4, 5], [1], QueryList([1])],
         [[1, 2, 3, 4, 5], [1, 4], QueryList([1, 4])],
-        [[1, 2, 3, 4, 5], lambda val: 1 == val, QueryList([1])],
-        [[1, 2, 3, 4, 5], lambda val: 2 == val, QueryList([2])],
+        [[1, 2, 3, 4, 5], lambda val: val == 1, QueryList([1])],
+        [[1, 2, 3, 4, 5], lambda val: val == 2, QueryList([2])],
     ],
 )
 def test_filter(
